/** 
 *   DGPS - Data.
 *
 *   (c) Copyright 2007 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#ifndef _DGPS_DATA_H
#define _DGPS_DATA_H

//#include <time.h>
#include "parse_tools.h"
#include "dgps_conf.h"

#define MAX_BUFF_LEN 160

typedef enum {
	LEAD_CODE_UNKNOW = 0,
	LEAD_CODE_XOBS,
	LEAD_CODE_XOHD,
} LEAD_CODE;


struct data_line {
	char line[MAX_BUFF_LEN];
	int len;
	LEAD_CODE code; /* lead code */
	int valid_flag;
};

struct epoch {
	double sec;      /* seconds */
	int min;         /* minutes */
	int hour;        /* hours */
	int mday;        /* day of the month */
	int mon;         /* month */
	int year;        /* year */
	int ep;
	int num_sat;
	int sat_list[12];
	int sat_valid_list[12]; /* 0 or 1 invalid; 2: valid */
	char sat[24][81]; /* two lines for each sattelite */
};

struct rinex_heder {
	struct configuration *comment;      /* Add comment to navigation   */
	struct configuration *agency;	    /* Define name of agency       */
	struct configuration *markername;   /* Define marker name	   */   
	struct configuration *markernum;    /* Define marker number	   */   
	struct configuration *observer;	    /* Define name of observer     */
	struct configuration *recnum;	    /* Define receiver number      */
	struct configuration *antnum;       /* Define antenna number       */
	struct configuration *antype;	    /* Define antenna type	   */
	struct configuration *antdn;	    /* Define antenna delta North  */    
	struct configuration *antde;	    /* Define antenna delta East   */
	struct configuration *antdh;	    /* Define antenna delta Height */

	struct configuration *conf; /* Real structure with mem assignment */
};			    


int dgps_get_line(int fd, struct data_line *dl);
struct rinex_heder *rinex_heder_get_conf(char *file);
int free_rinex_heder(struct rinex_heder *rh);
int set_rinex_heder(int fd, struct rinex_heder *rh);
int line_is_epoch( char *line);
int parse_epoch_line( char *line, struct epoch *ep);
int print_epoch(int fd, struct epoch *ep);

int save_flash(int fd);
int reset_conf(int fd);
int set_logging(int fd, struct dgps_conf *dc);
int set_unlogging(int fd);

#endif /* ifndef _DGPS_DATA_H */
